    Mac OS X            	   2                                             ATTR ߀       ,                    ,  #com.latenitesoft.squeeze.signature   bplist00X$versionX$objectsY$archiverT$top U$null	

^lastCompressedV$class_uncompressedSize#A))-HvBZ$classnameX$classes_SQCompressionSignature_SQCompressionSignatureXNSObject_NSKeyedArchiverTroot#-27;AHW^qz|                            